==> timeago-0.0.1.tar.gz: lib/src/i18/es_short_messages.dart <==
library timeago.es_short_messages;

import 'package:intl/intl.dart';
import 'package:intl/message_lookup_by_library.dart';

final messages = new MessageLookup();

class MessageLookup extends MessageLookupByLibrary {
  get localeName => 'messages';

  static prefixAgo() => "";
  static prefixFromNow() => "";
  static suffixAgo() => "";
  static suffixFromNow() => "";

  static lessThanOneMinute() => "~1m";
  static aboutAMinute() => "1m";
  static minutes(minutes) =>
      "${Intl.plural(minutes, zero: '', one: '${minutes}m', other: '${minutes}m')}";
  static aboutAnHour() => "~1h";
  static hours(hours) =>
      "${Intl.plural(hours, zero: '', one: '${hours}h', other: '${hours}h')}";
  static aDay() => "~1d";
  static days(days) =>
      "${Intl.plural(days, zero: '', one: '${days}d', other: '${days}d')}";
  static aboutAMonth() => "~1me";
  static months(months) =>
      "${Intl.plural(months, zero: '', one: '${months}me', other: '${months}me')}";
  static aboutAYear() => "~1a";
  static years(years) =>
      "${Intl.plural(years, zero: '', one: '${years}a', other: '${years}a')}";

  static wordSeparator() => " ";

  final messages = const {
    "prefixAgo": prefixAgo,
    "prefixFromNow": prefixFromNow,
    "suffixAgo": suffixAgo,
    "suffixFromNow": suffixFromNow,
    "lessThanOneMinute": lessThanOneMinute,
    "aboutAMinute": aboutAMinute,
    "minutes": minutes,
    "aboutAnHour": aboutAnHour,
    "hours": hours,
    "aDay": aDay,
    "days": days,
    "aboutAMonth": aboutAMonth,
    "months": months,
    "aboutAYear": aboutAYear,
    "years": years,
    "wordSeparator": wordSeparator
  };
}

==> timeago-1.0.2.tar.gz: lib/src/i18/es_short_messages.dart <==
library timeago.es_short_messages;

import 'package:intl/intl.dart';
import 'package:intl/message_lookup_by_library.dart';

final messages = new MessageLookup();

class MessageLookup extends MessageLookupByLibrary {
  get localeName => 'messages';

  static prefixAgo() => "";
  static prefixFromNow() => "";
  static suffixAgo() => "";
  static suffixFromNow() => "";

  static lessThanOneMinute() => "ahora";
  static aboutAMinute() => "1 min";
  static minutes(minutes) =>
      "${Intl.plural(minutes, zero: '', one: '${minutes} min', other: '${minutes} min')}";
  static aboutAnHour() => "~1 hr";
  static hours(hours) =>
      "${Intl.plural(hours, zero: '', one: '${hours} hr', other: '${hours} hr')}";
  static aDay() => "~1 día";
  static days(days) =>
      "${Intl.plural(days, zero: '', one: '${days} día', other: '${days} día')}";
  static aboutAMonth() => "~1 mes";
  static months(months) =>
      "${Intl.plural(months, zero: '', one: '${months} meses', other: '${months} meses')}";
  static aboutAYear() => "~1 año";
  static years(years) =>
      "${Intl.plural(years, zero: '', one: '${years} año', other: '${years} año')}";

  static wordSeparator() => " ";

  final messages = const {
    "prefixAgo": prefixAgo,
    "prefixFromNow": prefixFromNow,
    "suffixAgo": suffixAgo,
    "suffixFromNow": suffixFromNow,
    "lessThanOneMinute": lessThanOneMinute,
    "aboutAMinute": aboutAMinute,
    "minutes": minutes,
    "aboutAnHour": aboutAnHour,
    "hours": hours,
    "aDay": aDay,
    "days": days,
    "aboutAMonth": aboutAMonth,
    "months": months,
    "aboutAYear": aboutAYear,
    "years": years,
    "wordSeparator": wordSeparator
  };
}
